/**
 * @fileoverview Home page component for the tattoo studio website.
 * Features a hero slideshow, about section, features, and call-to-action.
 */

import React, { useState, useEffect, useCallback, memo } from 'react'
import { Link } from 'react-router-dom'

/**
 * Feature card component for displaying studio features
 * @param {Object} props - Component props
 * @param {string} props.title - Feature title
 * @param {string} props.description - Feature description
 * @param {string} props.icon - Feature icon (emoji)
 * @returns {JSX.Element} Feature card component
 */
const FeatureCard = memo(({ title, description, icon }) => (
  <div className="text-center p-6 bg-white rounded-lg shadow-sm hover:shadow-md transition-shadow duration-300">
    <div className="text-4xl mb-4">{icon}</div>
    <h3 className="text-xl font-serif font-semibold mb-3">{title}</h3>
    <p className="text-gray-600 leading-relaxed">{description}</p>
  </div>
))

/**
 * Hero slideshow images data
 * @type {Array<{id: number, src: string, alt: string, artist: string, style: string}>}
 */
const heroImages = [
  {
    id: 1,
    src: 'https://images.unsplash.com/photo-1565058379802-bbe93b2f703a?w=1920&h=1080&fit=crop',
    alt: 'Detailed realism tattoo artwork',
    artist: 'Sarah Chen',
    style: 'Realism'
  },
  {
    id: 2,
    src: 'https://images.unsplash.com/photo-1598300042247-d088f8ab3a91?w=1920&h=1080&fit=crop',
    alt: 'Neo-traditional tattoo design',
    artist: 'Marcus Rodriguez',
    style: 'Neo-Traditional'
  },
  {
    id: 3,
    src: 'https://images.unsplash.com/photo-1611501275019-9b5cda994e8d?w=1920&h=1080&fit=crop',
    alt: 'Intricate dot-work tattoo',
    artist: 'Elena Volkov',
    style: 'Dot-work'
  }
]

/**
 * Features data for the studio highlights section
 * @type {Array<{title: string, description: string, icon: string}>}
 */
const features = [
  {
    title: 'Master Artists',
    description: 'Our team consists of award-winning artists with years of experience and specialized expertise.',
    icon: '🎨'
  },
  {
    title: 'Custom Designs',
    description: 'Every piece is uniquely designed for you. No flash sheets, no compromises on your vision.',
    icon: '✨'
  },
  {
    title: 'Sterile Environment',
    description: 'State-of-the-art sterilization and safety protocols ensure your health and peace of mind.',
    icon: '🛡️'
  },
  {
    title: 'Premium Equipment',
    description: 'We use only the finest needles, inks, and equipment for superior results and comfort.',
    icon: '⚡'
  },
  {
    title: 'Lifetime Support',
    description: 'Comprehensive aftercare guidance and touch-up services to keep your tattoo looking perfect.',
    icon: '🤝'
  },
  {
    title: 'Consultation Process',
    description: 'Detailed consultations ensure we understand your vision and create the perfect design.',
    icon: '💭'
  }
]

/**
 * Home page component
 * @returns {JSX.Element} The home page
 */
function Home() {
  const [currentSlide, setCurrentSlide] = useState(0)
  const [isLoaded, setIsLoaded] = useState(false)

  useEffect(() => {
    setIsLoaded(true)
    const timer = setInterval(() => {
      setCurrentSlide((prev) => (prev + 1) % heroImages.length)
    }, 5000)

    return () => clearInterval(timer)
  }, [])

  /**
   * Navigate to the next slide in the hero carousel
   */
  const nextSlide = useCallback(() => {
    setCurrentSlide((prev) => (prev + 1) % heroImages.length)
  }, []) 

  /**
   * Navigate to the previous slide in the hero carousel
   */
  const prevSlide = useCallback(() => {
    setCurrentSlide((prev) => (prev - 1 + heroImages.length) % heroImages.length)
  }, [])

  return (
    <div className="pt-16 lg:pt-20">
      {/* Hero Section */}
      <section 
        className="relative h-screen overflow-hidden" 
        aria-label="Hero slideshow"
        role="region"
      >
        {/* Slideshow */}
        <div className="relative w-full h-full">
          {heroImages.map((image, index) => (
            <div
              key={image.id}
              className={`absolute inset-0 transition-opacity duration-1000 ${
                index === currentSlide ? 'opacity-100' : 'opacity-0'
              }`}
            >
              <div 
                className="w-full h-full bg-cover bg-center bg-gray-900"
                style={{
                  backgroundImage: `linear-gradient(rgba(0, 0, 0, 0.4), rgba(0, 0, 0, 0.4)), url(${image.src})`,
                }}
                role="img"
                aria-label={image.alt}
              >
                {/* Fallback content removed since we now have real images */}
              </div>
            </div>
          ))}
        </div>

        {/* Navigation Arrows */}
        <button
          onClick={prevSlide}
          className="absolute left-4 top-1/2 transform -translate-y-1/2 p-2 rounded-full bg-black/50 text-white hover:bg-black/70 transition-all duration-300 focus:outline-none focus:ring-2 focus:ring-accent"
          aria-label="Previous image"
        >
          <svg className="w-6 h-6" fill="none" stroke="currentColor" viewBox="0 0 24 24">
            <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M15 19l-7-7 7-7" />
          </svg>
        </button>
        <button
          onClick={nextSlide}
          className="absolute right-4 top-1/2 transform -translate-y-1/2 p-2 rounded-full bg-black/50 text-white hover:bg-black/70 transition-all duration-300 focus:outline-none focus:ring-2 focus:ring-accent"
          aria-label="Next image"
        >
          <svg className="w-6 h-6" fill="none" stroke="currentColor" viewBox="0 0 24 24">
            <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M9 5l7 7-7 7" />
          </svg>
        </button>

        {/* Slide Indicators */}
        <div className="absolute bottom-8 left-1/2 transform -translate-x-1/2 flex space-x-2">
          {heroImages.map((_, index) => (
            <button
              key={index}
              onClick={() => setCurrentSlide(index)}
              className={`w-3 h-3 rounded-full transition-all duration-300 ${
                index === currentSlide ? 'bg-accent' : 'bg-white/50 hover:bg-white/70'
              }`}
              aria-label={`Go to slide ${index + 1}`}
            />
          ))}
        </div>

        {/* Hero Content */}
        <div className="absolute inset-0 flex items-center justify-center">
          <div 
            className={`text-center text-white px-4 transform transition-all duration-1000 ${
              isLoaded ? 'translate-y-0 opacity-100' : 'translate-y-8 opacity-0'
            }`}
            aria-live="polite"
          >
            <h1 className="text-4xl md:text-6xl lg:text-7xl font-serif font-bold mb-6 text-shadow-lg">
              Ink With Intention
            </h1>
            <p className="text-lg md:text-xl lg:text-2xl mb-8 max-w-2xl mx-auto text-gray-100 leading-relaxed">
              Where artistry meets precision. Custom tattoos crafted by master artists who understand that every line tells your story.
            </p>
            <div className="flex flex-col sm:flex-row gap-4 justify-center">
              <Link
                to="/booking"
                className="btn-primary inline-block transform hover:scale-105 transition-all duration-300"
              >
                Book Consultation
              </Link>
              <Link
                to="/portfolio"
                className="btn-secondary inline-block bg-white/10 border-white text-white hover:bg-white hover:text-black transform hover:scale-105 transition-all duration-300"
              >
                View Portfolio
              </Link>
            </div>
          </div>
        </div>
      </section>

      {/* About Section */}
      <section className="section-padding py-20 lg:py-32" aria-labelledby="about-heading">
        <div className="container-max">
          <div className="grid grid-cols-1 lg:grid-cols-2 gap-12 lg:gap-20 items-center">
            <div className="space-y-6">
              <h2 id="about-heading" className="text-3xl md:text-4xl lg:text-5xl font-serif font-bold">
                Artistry in Every Line
              </h2>
              <p className="text-lg text-gray-600 leading-relaxed">
                At Ink With Intention Studio, we believe that every tattoo tells a story. Our team of master artists 
                combines traditional techniques with contemporary innovation to create pieces that are 
                not just tattoos, but works of art that will stand the test of time.
              </p>
              <p className="text-lg text-gray-600 leading-relaxed">
                From intricate dot-work to photorealistic portraits, neo-traditional designs to 
                minimalist line art, we specialize in bringing your vision to life with uncompromising 
                quality and attention to detail.
              </p>
              <div className="pt-4">
                <Link
                  to="/artists"
                  className="inline-flex items-center text-black hover:text-accent transition-colors duration-300 font-medium"
                >
                  Meet Our Artists
                  <svg className="ml-2 w-5 h-5" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                    <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M17 8l4 4m0 0l-4 4m4-4H3" />
                  </svg>
                </Link>
              </div>
            </div>
            <div className="relative">
              <div className="aspect-square bg-gray-200 rounded-lg overflow-hidden">
                <img 
                  src="https://images.unsplash.com/photo-1567427018141-0584cfcbf1b8?w=600&h=600&fit=crop"
                  alt="Professional tattoo studio interior"
                  className="w-full h-full object-cover"
                />
              </div>
            </div>
          </div>
        </div>
      </section>

      {/* Features Section */}
      <section className="bg-gray-50 section-padding py-20" aria-labelledby="features-heading">
        <div className="container-max">
          <div className="text-center mb-16">
            <h2 id="features-heading" className="text-3xl md:text-4xl font-serif font-bold mb-4">
              Why Choose Ink With Intention
            </h2>
            <p className="text-lg text-gray-600 max-w-2xl mx-auto">
              We're committed to providing an exceptional experience from consultation to aftercare.
            </p>
          </div>
          
          <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
            {features.map((feature, index) => (
              <FeatureCard
                key={index}
                title={feature.title}
                description={feature.description}
                icon={feature.icon}
              />
            ))}
          </div>
        </div>
      </section>

      {/* CTA Section */}
      <section className="section-padding py-20" aria-labelledby="cta-heading">
        <div className="container-max">
          <div className="text-center">
            <h2 id="cta-heading" className="text-3xl md:text-4xl font-serif font-bold mb-6">
              Ready to Start Your Journey?
            </h2>
            <p className="text-lg text-gray-600 mb-8 max-w-2xl mx-auto">
              Book a consultation today and let's bring your vision to life. Our artists are ready to 
              create something extraordinary just for you.
            </p>
            <Link
              to="/booking"
              className="btn-primary inline-block"
            >
              Book Your Consultation
            </Link>
          </div>
        </div>
      </section>
    </div>
  )
}

export default Home